@@ -26,7 +26,6 @@
 #ifndef DIALOGS_H
 #define DIALOGS_H
 
-#ifndef USING_PCH
 #include <QDialog>
 #include <QSlider>
 #include <QGroupBox>
@@ -40,7 +39,6 @@
 #include <QLabel>
 #include <QFrame>
 #include <QPushButton>
-#endif
 
 #include "misc.h"
 
@@ -48,7 +46,7 @@ class IntervalDialog : public QDialog
 {
     Q_OBJECT
   public:
-    IntervalDialog(const char *ed_txt, bool toggle_state);
+    IntervalDialog(const char *ed_txt, bool toggle_state, QWidget *parent = nullptr);
 
   protected slots:
     void done_dialog();
@@ -68,7 +66,7 @@ class SliderDialog : public QDialog
 {
     Q_OBJECT
   public:
-    SliderDialog(int defaultval, int minval, int maxval);
+    SliderDialog(int defaultval, int minval, int maxval, QWidget *parent = nullptr);
 
     QString ed_result;
 
@@ -87,7 +85,7 @@ class PermissionDialog : public QDialog
 {
     Q_OBJECT
   public:
-    PermissionDialog(QString msg, QString passwd);
+    PermissionDialog(QString msg, QString passwd, QWidget *parent = nullptr);
     QLineEdit *lined;
     QLabel *label;
 
@@ -105,7 +103,7 @@ class SchedDialog : public QDialog
 {
     Q_OBJECT
   public:
-    SchedDialog(int policy, int prio);
+    SchedDialog(int policy, int prio, QWidget *parent = nullptr);
 
     int out_prio;
     int out_policy;
