@@ -200,14 +200,16 @@ void Lookup::do_child(int fd)
         }
         else
         {
-            strncpy(buf, h->h_name, sizeof(buf));
+            strncpy(buf, h->h_name, 256);
+            buf[255] = '\0';
         }
         // if parent died, we'll get SIGPIPE here and terminate
         // automatically
-        write(fd, &addr, sizeof(addr));
+        ssize_t w = write(fd, &addr, sizeof(addr));
         int len = strlen(buf);
-        write(fd, &len, sizeof(len));
-        write(fd, buf, len);
+        w = write(fd, &len, sizeof(len));
+        w = write(fd, buf, len);
+        Q_UNUSED(w)
     }
 }
 
